@@ -1,24 +1,18 @@
-from teleschlafmedizin.model.PSGSignal import PSGSignal
-from teleschlafmedizin.model.Annotation import Annotation
-from teleschlafmedizin.model.recordManager.RecordMeta import Channel, Record, RecordAnnotation, RecordChannel
-from pyPhases.util.Logger import classLogger
-from teleschlafmedizin.model.util.DynamicModule import DynamicModule
+from .util.DynamicModule import DynamicModule
 from . import recordLoaders as recordManagerPath
 
 
-
-
 class RecordWriter:
     recordWriter = DynamicModule(recordManagerPath)
-    record: Record = None
+    record = None
 
     def writerRecord(recordName):
         pass
 
-    def writeAnnotation(self, annotation: Annotation):
+    def writeAnnotation(self, annotation):
         pass
 
-    def writeDataAnnotation(self, dataAnnotation: RecordAnnotation):
+    def writeDataAnnotation(self, dataAnnotation):
         """Writes a RecordAnnotationannotation to the Record
 
         Args:
