@@ -2,7 +2,7 @@ import xml.etree.ElementTree as ET
 
 from pyPhases.util.Logger import classLogger
 
-from ..RecordLoader import ParseError
+from pyPhasesRecordloader.RecordLoader import ParseError
 
 
 @classLogger
